@@ -8,12 +8,15 @@ use base 'Dancer::Session::Abstract';
 use Dancer::Logger;
 use Dancer::ModuleLoader;
 use Dancer::Config 'setting';
-use Dancer::FileUtils qw(path open_file);
+use Dancer::FileUtils qw(path set_file_mode);
+use File::Copy;
+use File::Temp qw(tempfile);
 
 # static
 
 sub init {
-    my ($class) = @_;
+    my $self = shift;
+    $self->SUPER::init(@_);
 
     croak "YAML is needed and is not installed"
       unless Dancer::ModuleLoader->load('YAML');
@@ -56,6 +59,11 @@ sub yaml_file {
     return path(setting('session_dir'), "$id.yml");
 }
 
+sub tmp_yaml_file {
+    my ($id) = @_;
+    return path(setting('session_dir'), "$id.tmp");
+}
+
 sub destroy {
     my ($self) = @_;
     use Dancer::Logger;
@@ -66,9 +74,12 @@ sub destroy {
 
 sub flush {
     my $self = shift;
-    my $sessionfh = open_file('>', yaml_file($self->id));
-    print {$sessionfh} YAML::Dump($self);
-    close $sessionfh;
+    my ( $fh, $tmpname ) =
+      tempfile( $self->id . '.XXXXXXXX', DIR => setting('session_dir') );
+    set_file_mode($fh);
+    print {$fh} YAML::Dump($self);
+    close $fh;
+    move($tmpname, yaml_file($self->id));
     return $self;
 }
 
